import {
  Autocomplete,
  Box,
  TextField,
  Typography,
  FormControlLabel,
  Checkbox,
  Grid,
  Paper,
} from "@mui/material";
import { Create, useAutocomplete } from "@refinedev/mui";
import { useForm } from "@refinedev/react-hook-form";
import { useEffect, useState } from "react";
import { Controller } from "react-hook-form";

const TRANSFER_FIELDS = [
  { name: "bus", label: "Автобус" },
  { name: "metro_blue", label: "Метро (синяя)" },
  { name: "metro_green", label: "Метро (зеленая)" },
  { name: "metro_orange", label: "Метро (оранжевая)" },
  { name: "metro_purple", label: "Метро (фиолетовая)" },
  { name: "metro_red", label: "Метро (красная)" },
  { name: "train", label: "Электричка" },
  { name: "tram", label: "Трамвай" },
  { name: "trolleybus", label: "Троллейбус" },
];

export const StationCreate = () => {
  const {
    saveButtonProps,
    refineCore: { formLoading },
    register,
    setValue,
    control,
    getValues,
    watch,
    formState: { errors },
  } = useForm({
    refineCoreProps: {
      resource: "station",
    },
  });

  const [coordinates, setCoordinates] = useState("");

  const handleCoordinatesChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setCoordinates(e.target.value);
    const [lat, lon] = e.target.value
      .replace(/,/g, "") // Remove all commas from the string
      .split(" ")
      .map((s) => s.trim());
    console.log(lat, lon);
    setValue("latitude", lat);
    setValue("longitude", lon);
  };

  const directions = [
    {
      label: "Прямой",
      value: true,
    },
    {
      label: "Обратный",
      value: false,
    },
  ];

  const [routeDirection, setRouteDirection] = useState(false);

  const { autocompleteProps: cityAutocompleteProps } = useAutocomplete({
    resource: "city",
    onSearch: (value) => [
      {
        field: "name",
        operator: "contains",
        value,
      },
    ],
  });

  return (
    <Create isLoading={formLoading} saveButtonProps={saveButtonProps}>
      <Box
        component="form"
        sx={{ display: "flex", flexDirection: "column" }}
        autoComplete="off"
      >
        <TextField
          {...register("name", {
            required: "Это поле является обязательным",
          })}
          error={!!(errors as any)?.name}
          helperText={(errors as any)?.name?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{ shrink: true }}
          type="text"
          label={"Название *"}
          name="name"
        />
        <TextField
          {...register("system_name", {
            required: "Это поле является обязательным",
          })}
          error={!!(errors as any)?.system_name}
          helperText={(errors as any)?.system_name?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{ shrink: true }}
          type="text"
          label={"Системное название *"}
          name="system_name"
        />
        <TextField
          {...register("address", {
            // required: 'Это поле является обязательным',
          })}
          error={!!(errors as any)?.address}
          helperText={(errors as any)?.address?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{ shrink: true }}
          type="text"
          label={"Адрес"}
          name="address"
        />

        <TextField
          {...register("description", {
            // required: 'Это поле является обязательным',
          })}
          error={!!(errors as any)?.description}
          helperText={(errors as any)?.description?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{ shrink: true }}
          type="text"
          label={"Описание"}
          name="description"
        />
        <input
          type="hidden"
          {...register("direction", {
            value: routeDirection,
          })}
        />

        <Autocomplete
          options={directions}
          defaultValue={directions.find((el) => el.value == false)}
          onChange={(_, element) => {
            if (element) {
              setValue("direction", element.value);
              setRouteDirection(element.value);
            }
          }}
          renderInput={(params) => (
            <TextField
              {...params}
              label="Прямой/обратный маршрут"
              margin="normal"
              variant="outlined"
              error={!!errors.arms}
              helperText={(errors as any)?.arms?.message}
              required
            />
          )}
        />
        <TextField
          value={coordinates}
          onChange={handleCoordinatesChange}
          error={!!(errors as any)?.latitude}
          helperText={(errors as any)?.latitude?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{ shrink: true }}
          type="text"
          label={"Координаты *"}
        />

        <input
          type="hidden"
          {...register("latitude", {
            value: coordinates.split(",")[0],
            setValueAs: (value) => {
              if (value === "") {
                return 0;
              }
              return Number(value);
            },
          })}
        />
        <input
          type="hidden"
          {...register("longitude", {
            value: coordinates.split(",")[1],
            setValueAs: (value) => {
              if (value === "") {
                return 0;
              }
              return Number(value);
            },
          })}
        />

        <Controller
          control={control}
          name="city_id"
          rules={{ required: "Это поле является обязательным" }}
          defaultValue={null}
          render={({ field }) => (
            <Autocomplete
              {...cityAutocompleteProps}
              value={
                cityAutocompleteProps.options.find(
                  (option) => option.id === field.value
                ) || null
              }
              onChange={(_, value) => {
                field.onChange(value?.id || "");
              }}
              getOptionLabel={(item) => {
                return item ? item.name : "";
              }}
              isOptionEqualToValue={(option, value) => {
                return option.id === value?.id;
              }}
              filterOptions={(options, { inputValue }) => {
                return options.filter((option) =>
                  option.name.toLowerCase().includes(inputValue.toLowerCase())
                );
              }}
              renderInput={(params) => (
                <TextField
                  {...params}
                  label="Выберите город"
                  margin="normal"
                  variant="outlined"
                  error={!!errors.city_id}
                  helperText={(errors as any)?.city_id?.message}
                  required
                />
              )}
            />
          )}
        />

        <Box sx={{ visibility: "hidden" }}>
          <TextField
            {...register("offset_x", {
              // required: 'Это поле является обязательным',
              setValueAs: (value) => {
                if (value === "") {
                  return 0;
                }
              },
            })}
            error={!!(errors as any)?.offset_x}
            helperText={(errors as any)?.offset_x?.message}
            margin="normal"
            fullWidth
            InputLabelProps={{ shrink: true }}
            type="number"
            label={"Смещение (X)"}
            name="offset_x"
          />

          <TextField
            {...register("offset_y", {
              setValueAs: (value) => {
                if (value === "") {
                  return 0;
                }
              },
              // required: 'Это поле является обязательным',
            })}
            error={!!(errors as any)?.offset_y}
            helperText={(errors as any)?.offset_y?.message}
            margin="normal"
            fullWidth
            InputLabelProps={{ shrink: true }}
            type="number"
            label={"Смещение (Y)"}
            name="offset_y"
          />
        </Box>
      </Box>

      {/* Группа полей пересадок */}
      <Paper hidden sx={{ p: 2, mt: 2 }}>
        <Typography variant="h6" gutterBottom>
          Пересадки
        </Typography>
        <Grid container spacing={2}>
          {TRANSFER_FIELDS.map((field) => (
            <Grid item xs={12} sm={6} md={4} key={field.name}>
              <TextField
                {...register(`transfers.${field.name}`)}
                error={!!(errors as any)?.transfers?.[field.name]}
                helperText={(errors as any)?.transfers?.[field.name]?.message}
                margin="normal"
                fullWidth
                InputLabelProps={{ shrink: true }}
                type="text"
                label={field.label}
                name={`transfers.${field.name}`}
              />
            </Grid>
          ))}
        </Grid>
      </Paper>
    </Create>
  );
};
